%bcond_with check

# comment out when not a pre-release
#define prerel	rc2

%define rel	1

Name:           meson
Version:        1.7.0
Release:        %mkrel %{?prerel: -c %{prerel}} %{rel}
Summary:        High productivity build system
Group:          System/Packaging
License:        ASL 2.0
URL:            https://mesonbuild.com/
Source0:        https://github.com/mesonbuild/meson/releases/download/%{version}%{?prerel:%{prerel}}/%{name}-%{version}%{?prerel:%{prerel}}.tar.gz
Source1:        https://github.com/mesonbuild/meson/releases/download/%{version}%{?prerel:%{prerel}}/%{name}-%{version}%{?prerel:%{prerel}}.tar.gz.asc
# Backported from upstream commit
#
# Based on patch from
# https://github.com/mesonbuild/meson/pull/11484
Patch101:       0001-Add-support-for-runstatedir.patch
BuildArch:      noarch
BuildRequires:  git-core
BuildRequires:  pkgconfig(python3)
BuildRequires:  python3dist(setuptools)

%if %{with check}
BuildRequires:  locales
BuildRequires:  ninja

# Various languages
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  gcc-gfortran
BuildRequires:  gcc-objc
BuildRequires:  gcc-objc++
BuildRequires:  java-devel
BuildRequires:  libasan-devel
BuildRequires:  llvm-devel
BuildRequires:  mono-core
BuildRequires:  pkgconfig(mono)
BuildRequires:  rust

# Various libs support
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  gettext
BuildRequires:  git
BuildRequires:  gtk-doc
BuildRequires:  itstool
BuildRequires:  locales-en
BuildRequires:  vala
BuildRequires:  vala-tools
BuildRequires:  boost-devel
BuildRequires:  gnustep-base-devel
BuildRequires:  cups-devel
BuildRequires:  libwmf-devel
BuildRequires:  pcap-devel
BuildRequires:  qtbase5-devel
BuildRequires:  qttools5
BuildRequires:  wxgtk3.0-devel
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(glib-sharp-2.0)
BuildRequires:  pkgconfig(gmock)
BuildRequires:  pkgconfig(gtest)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(ompi)
BuildRequires:  pkgconfig(protobuf)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(vulkan)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  python3-gobject3
BuildRequires:  python3dist(cython)
%endif

Requires:       ninja
Requires:       python3dist(setuptools)

%description
Meson is a build system designed to optimize programmer productivity.
It aims to do this by providing simple, out-of-the-box support for
modern software development tools and practices, such as unit tests,
coverage reports, Valgrind, CCache and the like.

%prep
%autosetup -p1 %{?prerel: -n %{name}-%{version}%{prerel}}

%py3_shebang_fix .

# Remove MPI tests for now because it is complicated to run.
rm -rf "test cases/frameworks/17 mpi"

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files mesonbuild

# install meson rpm macro helper
install -D -m 0644 data/macros.%{name} %{buildroot}%{_rpmmacrodir}/macros.%{name}

install -D -m 0644 -t %{buildroot}%{_datadir}/bash-completion/completions/ data/shell-completions/bash/meson
install -D -m 0644 -t %{buildroot}%{_datadir}/zsh/site-functions/ data/shell-completions/zsh/_meson

%if %{with check}
%check
export MESON_PRINT_TEST_OUTPUT=1
export LC_ALL=UTF-8
%{__python3} ./run_tests.py
%endif

%files -f %{pyproject_files}
%doc README.md
%license COPYING
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1.*
%{_rpmmacrodir}/macros.%{name}
%{_datadir}/polkit-1/actions/com.mesonbuild.install.policy
%{_datadir}/bash-completion/completions/meson
%{_datadir}/zsh/site-functions/_meson


%changelog
* Mon Jan 27 2025 daviddavid <daviddavid> 1.7.0-1.mga10
+ Revision: 2142676
- new version: 1.7.0

* Tue Dec 17 2024 daviddavid <daviddavid> 1.6.1-1.mga10
+ Revision: 2125724
- new version: 1.6.1

* Mon Oct 21 2024 daviddavid <daviddavid> 1.6.0-1.mga10
+ Revision: 2109405
- new version: 1.6.0

* Sat Sep 21 2024 daviddavid <daviddavid> 1.5.2-1.mga10
+ Revision: 2099753
- new version: 1.5.2

* Thu Aug 01 2024 daviddavid <daviddavid> 1.5.1-1.mga10
+ Revision: 2083383
- new version: 1.5.1

* Mon Jun 03 2024 daviddavid <daviddavid> 1.4.1-1.mga10
+ Revision: 2069560
- new version: 1.4.1

* Thu Mar 21 2024 daviddavid <daviddavid> 1.4.0-1.mga10
+ Revision: 2051154
- new version 1.4.0

* Thu Feb 15 2024 daviddavid <daviddavid> 1.3.2-1.mga10
+ Revision: 2041424
- new version: 1.3.2

* Fri Dec 29 2023 daviddavid <daviddavid> 1.3.1-1.mga10
+ Revision: 2023562
- new version: 1.3.1

* Mon Dec 18 2023 daviddavid <daviddavid> 1.3.0-1.mga10
+ Revision: 2018828
- new version: 1.3.0
- switch to pyproject
- install mseon bash-completion and meson site-functions files

* Thu Dec 07 2023 wally <wally> 1.2.3-2.mga10
+ Revision: 2014770
- rebuild for py3.12

* Wed Oct 25 2023 daviddavid <daviddavid> 1.2.3-1.mga10
+ Revision: 2001165
- new version: 1.2.3
- remove merged upstream patch

* Mon Oct 02 2023 daviddavid <daviddavid> 1.2.2-2.mga10
+ Revision: 1993029
- revert a commit which broke now mesa build
  * https://github.com/mesonbuild/meson/commit/36210f6
  * https://gitlab.freedesktop.org/mesa/mesa/-/issues/9908

* Sun Oct 01 2023 daviddavid <daviddavid> 1.2.2-1.mga10
+ Revision: 1992763
- new version: 1.2.2
- remove merged upstream patch

* Sat Sep 09 2023 wally <wally> 1.2.1-2.mga10
+ Revision: 1985578
- backport upstream patch to fix crash when installing a vala library and python sources

* Mon Aug 28 2023 daviddavid <daviddavid> 1.2.1-1.mga10
+ Revision: 1980521
- new version: 1.2.1

* Thu May 25 2023 kekepower <kekepower> 1.1.1-1.mga9
+ Revision: 1957971
- Update to version 1.1.1

* Tue Apr 11 2023 kekepower <kekepower> 1.1.0-1.mga9
+ Revision: 1952753
- Update to version 1.1.0

* Fri Feb 24 2023 kekepower <kekepower> 1.0.1-1.mga9
+ Revision: 1945209
- Update to version 1.0.1

* Fri Dec 23 2022 daviddavid <daviddavid> 1.0.0-1.mga9
+ Revision: 1926158
- new version: 1.0.0

* Sat Dec 17 2022 kekepower <kekepower> 1.0.0-0.rc2.1.mga9
+ Revision: 1924176
- Update to version 1.0.0rc2

* Sat Dec 10 2022 kekepower <kekepower> 1.0.0-0.rc1.1.mga9
+ Revision: 1920472
- Update to version 1.0.0rc1

* Mon Dec 05 2022 wally <wally> 0.64.1-2.mga9
+ Revision: 1918066
- suppress warning when using %%meson RPM macro

* Wed Nov 23 2022 kekepower <kekepower> 0.64.1-1.mga9
+ Revision: 1910448
- Update to version 0.64.1

* Sun Nov 06 2022 kekepower <kekepower> 0.64.0-1.mga9
+ Revision: 1904049
- Update to version 0.64.0

* Thu Oct 06 2022 kekepower <kekepower> 0.63.3-1.mga9
+ Revision: 1895164
- Update to version 0.63.3

* Sun Sep 04 2022 kekepower <kekepower> 0.63.2-1.mga9
+ Revision: 1883742
- Update to version 0.63.2

* Sat Aug 13 2022 kekepower <kekepower> 0.63.1-1.mga9
+ Revision: 1877308
- Update to version 0.63.1

* Tue Jul 05 2022 kekepower <kekepower> 0.63.0-1.mga9
+ Revision: 1867720
- Update to version 0.63.0

* Wed Apr 27 2022 kekepower <kekepower> 0.62.1-1.mga9
+ Revision: 1854540
- Update to version 0.62.1

* Sat Apr 16 2022 ghibo <ghibo> 0.62.0-1.mga9
+ Revision: 1850716
- Update to release 0.62.0

* Wed Mar 23 2022 umeabot <umeabot> 0.60.3-3.mga9
+ Revision: 1822110
- Mageia 9 Mass Rebuild

* Sat Feb 05 2022 wally <wally> 0.60.3-2.mga9
+ Revision: 1771778
- rebuild for python3.10

* Mon Jan 10 2022 tv <tv> 0.60.3-1.mga9
+ Revision: 1767594
- Bump rel so that BS stop installing 0.60.2 for gjs

* Mon Jan 10 2022 tv <tv> 0.60.3-0.1.mga9
+ Revision: 1767573
- 0.60.3
- 0.60.3

* Thu Dec 02 2021 wally <wally> 0.60.2-1.mga9
+ Revision: 1760576
- new version 0.60.2

* Sun Nov 14 2021 wally <wally> 0.60.1-1.mga9
+ Revision: 1756228
- new version 0.60.1

* Sat Sep 18 2021 wally <wally> 0.59.1-1.mga9
+ Revision: 1745711
- new version 0.59.1

* Thu May 20 2021 daviddavid <daviddavid> 0.58.0-2.mga9
+ Revision: 1725774
- backport upstream patch to fix flatten environment() initial values on interpreter (mesonbuild#8727)
- backport upstream patch to fix gtkdoc generation (mesonbuild#8744)

* Mon May 03 2021 daviddavid <daviddavid> 0.58.0-1.mga9
+ Revision: 1721002
- new version: 0.58.0

* Mon Apr 12 2021 daviddavid <daviddavid> 0.57.2-1.mga9
+ Revision: 1714813
- new version: 0.57.2

* Sun Mar 14 2021 wally <wally> 0.57.1-2.mga9
+ Revision: 1702576
- rebuild for python 3.9

* Thu Feb 25 2021 daviddavid <daviddavid> 0.57.1-1.mga9
+ Revision: 1691002
- new version: 0.57.1

* Sun Nov 08 2020 daviddavid <daviddavid> 0.56.0-1.mga8
+ Revision: 1643612
- new version: 0.56.0

* Sun Oct 18 2020 wally <wally> 0.55.3-2.mga8
+ Revision: 1636717
- restore runstatedir patch

* Mon Sep 14 2020 daviddavid <daviddavid> 0.55.3-1.mga8
+ Revision: 1626502
- new version: 0.55.3

* Fri Sep 11 2020 daviddavid <daviddavid> 0.55.2-1.mga8
+ Revision: 1624648
- new version: 0.55.2

* Tue Sep 01 2020 tv <tv> 0.55.1-2.mga8
+ Revision: 1620718
- remove patch that brokes building libvirt

* Mon Aug 24 2020 daviddavid <daviddavid> 0.55.1-1.mga8
+ Revision: 1618292
- new version: 0.55.1

* Tue Jul 14 2020 daviddavid <daviddavid> 0.55.0-1.mga8
+ Revision: 1605902
- new version: 0.55.0

* Wed Jun 17 2020 daviddavid <daviddavid> 0.54.3-1.mga8
+ Revision: 1593974
- new version: 0.54.3

* Sun May 17 2020 daviddavid <daviddavid> 0.54.2-1.mga8
+ Revision: 1585486
- new version: 0.54.2

* Fri May 01 2020 daviddavid <daviddavid> 0.54.1-1.mga8
+ Revision: 1577361
- new version: 0.54.1

* Sat Apr 11 2020 wally <wally> 0.54.0-2.mga8
+ Revision: 1566357
- add support for runstatedir

* Mon Mar 30 2020 daviddavid <daviddavid> 0.54.0-1.mga8
+ Revision: 1562405
- new version: 0.54.0

* Sat Feb 29 2020 daviddavid <daviddavid> 0.53.2-1.mga8
+ Revision: 1552183
- new version: 0.53.2

* Thu Feb 20 2020 umeabot <umeabot> 0.53.1-2.mga8
+ Revision: 1545880
- Mageia 8 Mass Rebuild

* Thu Jan 30 2020 daviddavid <daviddavid> 0.53.1-1.mga8
+ Revision: 1485393
- new version: 0.53.1

* Thu Dec 26 2019 wally <wally> 0.52.1-3.mga8
+ Revision: 1470134
- drop unneeded mageiafy rpm macros patch

* Wed Dec 25 2019 wally <wally> 0.52.1-2.mga8
+ Revision: 1470058
- update rpm macros patch (%%_vpath_srcdir and %%_vpath_builddir are defined in mageia-rpm-setup-build)

* Sun Dec 08 2019 daviddavid <daviddavid> 0.52.1-1.mga8
+ Revision: 1465122
- new version: 0.52.1

* Fri Oct 11 2019 daviddavid <daviddavid> 0.52.0-1.mga8
+ Revision: 1451895
- new version: 0.52.0

* Tue Sep 03 2019 wally <wally> 0.51.2-2.mga8
+ Revision: 1436780
- rebuild for python3.8

* Tue Aug 27 2019 daviddavid <daviddavid> 0.51.2-1.mga8
+ Revision: 1434437
- new version: 0.51.2

* Thu Jul 11 2019 daviddavid <daviddavid> 0.51.1-1.mga8
+ Revision: 1419967
- new version: 0.51.1

* Sun Jun 30 2019 daviddavid <daviddavid> 0.51.0-1.mga8
+ Revision: 1416263
- new version: 0.51.0
- remove merged upstream patch

* Wed Apr 17 2019 daviddavid <daviddavid> 0.50.1-1.mga7
+ Revision: 1391962
- new version: 0.50.1

* Mon Apr 08 2019 akien <akien> 0.50.0-3.mga7
+ Revision: 1386884
- Update Patch1 with the one that was merged upstream (same end result)
- Update Patch1 with the one that was merged upstream (same end result)

* Tue Mar 26 2019 akien <akien> 0.50.0-2.mga7
+ Revision: 1380380
- Add Fedora patch to set -Db_ndebug=true (rhbz#1692426)

* Sat Mar 16 2019 daviddavid <daviddavid> 0.50.0-1.mga7
+ Revision: 1377972
- new version: 0.50.0

* Tue Feb 05 2019 kekepower <kekepower> 0.49.2-1.mga7
+ Revision: 1363243
- Update to version 0.49.2

* Sun Jan 27 2019 wally <wally> 0.49.1-1.mga7
+ Revision: 1361290
- new version 0.49.1

* Sat Jan 05 2019 wally <wally> 0.49.0-2.mga7
+ Revision: 1349267
- rebuild for python3.7

* Mon Dec 10 2018 kekepower <kekepower> 0.49.0-1.mga7
+ Revision: 1339852
- Update to version 0.49.0
- Use python3dist()

* Fri Nov 09 2018 kekepower <kekepower> 0.48.2-1.mga7
+ Revision: 1329143
- Update to version 0.48.2

* Wed Oct 17 2018 kekepower <kekepower> 0.48.1-1.mga7
+ Revision: 1321743
- Update to version 0.48.1

* Thu Oct 11 2018 wally <wally> 0.48.0-1.mga7
+ Revision: 1319577
- new version 0.48.0

* Thu Sep 20 2018 umeabot <umeabot> 0.47.2-2.mga7
+ Revision: 1279508
- Mageia 7 Mass Rebuild

* Thu Aug 30 2018 daviddavid <daviddavid> 0.47.2-1.mga7
+ Revision: 1255701
- new version: 0.47.2
+ wally <wally>
- don't own dirs owned by polkit

* Mon Jul 23 2018 guillomovitch <guillomovitch> 0.47.1-1.mga7
+ Revision: 1245016
- new version 0.47.1

* Fri May 18 2018 kekepower <kekepower> 0.46.1-1.mga7
+ Revision: 1230390
- Change Release

* Fri May 18 2018 kekepower <kekepower> 0.46.1-0.1.mga7
+ Revision: 1230389
- Update to version 0.46.1

* Wed May 02 2018 kekepower <kekepower> 0.46.0-0.1.mga7
+ Revision: 1224594
- Update to version 0.46.0

* Thu Mar 22 2018 kekepower <kekepower> 0.45.1-0.1.mga7
+ Revision: 1211274
- Update to version 0.45.1

* Wed Mar 07 2018 kekepower <kekepower> 0.45.0-0.1.mga7
+ Revision: 1207129
- Update to version 0.45.0

* Wed Feb 21 2018 tv <tv> 0.44.1-0.1.mga7
+ Revision: 1203910
- new release (fix UTF-8 issues when building)

* Sun Dec 17 2017 wally <wally> 0.44.0-2.mga7
+ Revision: 1183048
- move UTF-8 locale fixes in rpm macros to ninja

* Sun Dec 17 2017 wally <wally> 0.44.0-1.mga7
+ Revision: 1183042
- build without tests
- new version 0.44.0
- rediff P0

* Thu Sep 21 2017 tv <tv> 0.42.1-1.mga7
+ Revision: 1156813
- new release

* Tue Aug 22 2017 ovitters <ovitters> 0.42.0-6.mga7
+ Revision: 1143299
- fix bug in locale forcing patch

* Tue Aug 22 2017 ovitters <ovitters> 0.42.0-5.mga7
+ Revision: 1143290
- improve locale forcing change

* Tue Aug 22 2017 ovitters <ovitters> 0.42.0-4.mga7
+ Revision: 1143285
- disable all buggy tests
- disable buggy test
- force UTF-8 LC_ALL for meson and ninja commands

* Mon Aug 21 2017 ovitters <ovitters> 0.42.0-3.mga7
+ Revision: 1142677
- require locales package

* Mon Aug 21 2017 ovitters <ovitters> 0.42.0-2.mga7
+ Revision: 1142645
- recommend locales package (easier for utf-8)

* Sat Aug 19 2017 daviddavid <daviddavid> 0.42.0-1.mga7
+ Revision: 1141655
- new version: 0.42.0

* Thu Aug 03 2017 tv <tv> 0.41.2-2.mga7
+ Revision: 1134480
- rebuild for new python

* Thu Jul 20 2017 daviddavid <daviddavid> 0.41.2-1.mga7
+ Revision: 1125513
- new version: 0.41.2

* Tue Jul 18 2017 tv <tv> 0.41.1-1.mga7
+ Revision: 1124743
- new release

* Sat Jun 03 2017 akien <akien> 0.38.0-3.mga6
+ Revision: 1106100
- Rebuild for wxgtk 3.0.3.1

* Thu Feb 02 2017 daviddavid <daviddavid> 0.38.0-2.mga6
+ Revision: 1084599
- mageiaify the meson macros

* Wed Feb 01 2017 daviddavid <daviddavid> 0.38.0-1.mga6
+ Revision: 1084507
- new version: 0.38.0

* Tue Dec 20 2016 daviddavid <daviddavid> 0.37.1-1.mga6
+ Revision: 1076236
- new version: 0.37.1

* Mon Dec 19 2016 daviddavid <daviddavid> 0.37.0-1.mga6
+ Revision: 1076164
- new version: 0.37.0

* Sun Dec 04 2016 daviddavid <daviddavid> 0.36.0-2.mga6
+ Revision: 1071916
- print test output during build

* Thu Nov 17 2016 daviddavid <daviddavid> 0.36.0-1.mga6
+ Revision: 1068018
- new version: 0.36.0
- add BRs itstool and vala-tools

* Tue Oct 18 2016 daviddavid <daviddavid> 0.35.1-1.mga6
+ Revision: 1061569
- new version: 0.35.1
- remove merged upstream patch

* Thu Oct 06 2016 daviddavid <daviddavid> 0.35.0-2.mga6
+ Revision: 1059159
- add upstream patch to fix missing dependency in gnome.mkenums test

* Tue Oct 04 2016 daviddavid <daviddavid> 0.35.0-1.mga6
+ Revision: 1058585
- new version: 0.35.0

* Sun Sep 25 2016 daviddavid <daviddavid> 0.34.0-1.mga6
+ Revision: 1056136
- imported package meson (based on Fedora)

